==> ng_bootstrap-0.6.7.tar.gz: lib/components/progress/progress.dart <==
import 'package:angular2/angular2.dart';
import 'dart:html';
import 'package:ng_bootstrap/components/template_outlet/bs_template_outlet.dart';

/// Creates a progress component
///
/// Base specifications: [bootstrap 4](http://v4-alpha.getbootstrap.com/components/progress/)
///
/// [demo](http://dart-league.github.io/ng_bootstrap/build/web/#progress)
@Component(selector: 'bs-progress',
    template: '''
<div class="progress-bar"
     role="progressbar"
     aria-valuenow="0"
     aria-valuemin="0"
     aria-valuemax="100"
     [style.width]="percentage">
  <div [style.width]="elementWidth">
    <template [bsTemplateOutlet]="labelTemplate" [ngOutletContext]="percentage"></template>
  </div>
</div>
<template [bsTemplateOutlet]="labelTemplate" [ngOutletContext]="percentage"></template>''',
    directives: const [BsTemplateOutletDirective])
class BsProgressComponent implements OnInit {

  /// if `true` changing `value` of progress bar will be animated (*note*: not supported by Bootstrap 4)
  @Input() bool animate = true;

  /// maximum value of the bar
  @Input() num max;

  /// value of the progress bar
  @Input() num value;

  String get percentage => (value / max * 100).toString() + '%';

  @ContentChild(TemplateRef)
  TemplateRef labelTemplate;

  /// Handles the width of the element
  String elementWidth;

  ElementRef _elementRef;

  BsProgressComponent(this._elementRef);

  /// initialize the attributes
  ngOnInit() {
    animate ??= true;
    max = max ??= 100;
    Element nativeElement = _elementRef.nativeElement;
    elementWidth = nativeElement.getComputedStyle().width;
    // TODO: change this event something else
    window.onResize.listen((e) {
      elementWidth = nativeElement.getComputedStyle().width;
    });
  }
}

==> ng_bootstrap-0.7.0.tar.gz: lib/components/progress/progress.dart <==
import 'package:angular/angular.dart';
import 'dart:html';
import 'package:ng_bootstrap/components/template_outlet/bs_template_outlet.dart';

/// Creates a progress component
///
/// Base specifications: [bootstrap 4](http://v4-alpha.getbootstrap.com/components/progress/)
///
/// [demo](http://dart-league.github.io/ng_bootstrap/build/web/#progress)
@Component(selector: 'bs-progress',
    template: '''
<div class="progress-bar"
     role="progressbar"
     aria-valuenow="0"
     aria-valuemin="0"
     aria-valuemax="100"
     [style.width]="percentage">
  <div [style.width]="elementWidth">
    <template [bsTemplateOutlet]="labelTemplate" [ngOutletContext]="percentage"></template>
  </div>
</div>
<template [bsTemplateOutlet]="labelTemplate" [ngOutletContext]="percentage"></template>''',
    directives: const [BsTemplateOutletDirective, CORE_DIRECTIVES])
class BsProgressComponent implements OnInit {

  /// if `true` changing `value` of progress bar will be animated (*note*: not supported by Bootstrap 4)
  @Input() bool animate = true;

  /// maximum value of the bar
  @Input() num max;

  /// value of the progress bar
  @Input() num value;

  String get percentage => (value / max * 100).toString() + '%';

  @ContentChild(TemplateRef)
  TemplateRef labelTemplate;

  /// Handles the width of the element
  String elementWidth;

  ElementRef _elementRef;

  BsProgressComponent(this._elementRef);

  /// initialize the attributes
  ngOnInit() {
    animate ??= true;
    max = max ??= 100;
    Element nativeElement = _elementRef.nativeElement;
    elementWidth = nativeElement.getComputedStyle().width;
    // TODO: change this event something else
    window.onResize.listen((e) {
      elementWidth = nativeElement.getComputedStyle().width;
    });
  }
}
